@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,8 +24,7 @@
 
 #include <QPixmap>
 
-namespace Gravatar
-{
+namespace Gravatar {
 class GravatarCachePrivate;
 class GRAVATAR_EXPORT GravatarCache : public QObject
 {
