@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,8 +23,7 @@
 #include <QDialog>
 #include "gravatar_export.h"
 
-namespace Gravatar
-{
+namespace Gravatar {
 class GravatarDownloadPixmapWidget;
 class GRAVATAR_EXPORT GravatarDownloadPixmapDialog : public QDialog
 {
